JitMemory

Struct JitMemory 

pub struct JitMemory { /* private fields */ }
A buffer for JIT code execution.

Example

use gaia_jit::JitMemory;

let mut jit = JitMemory::new(4096).unwrap();
// Write some machine code...
jit.write(&[0x90, 0xc3]).unwrap(); // nop; ret
jit.make_executable().unwrap();

unsafe {
    let f: unsafe extern "C" fn() = jit.as_fn();
    f();
}

Implementations

Source

impl JitMemory

pub fn new(capacity: usize) -> Result<Self>

Allocate a new JIT memory block with the given capacity.

pub fn write(&mut self, code: &[u8]) -> Result<()>

Write code into the buffer.

This method automatically ensures the memory is writable before writing, and restores the previous protection after if possible.

pub fn make_executable(&self) -> Result<*const u8>

Make the memory executable and return a pointer to the start.

pub fn make_writable(&self) -> Result<()>

Make the memory readable and writable again (e.g. for updates).

pub fn len(&self) -> usize

Get the current length of the code in the buffer.

pub fn capacity(&self) -> usize

Get the capacity of the buffer.

pub fn is_empty(&self) -> bool

Is the buffer empty?

pub fn as_slice(&self) -> &[u8]

As a slice of bytes (read-only).

pub unsafe fn as_fn<S>(&self) -> S

Cast the JIT memory to a function pointer of type S.